rid property
The correlation id an adapter stamped — the HTTP request this event happened under, for everything the shelf middleware wraps.
Implementation
final String? rid;
The correlation id an adapter stamped — the HTTP request this event happened under, for everything the shelf middleware wraps.
final String? rid;