PanelStyle class

Constructors

PanelStyle.of(BuildContext context)
factory

Properties

accent → Color
final
bad → Color
final
body → TextStyle
final
bodyStrong → TextStyle
final
caption → TextStyle
final
faint → Color
final
good → Color
final
hashCode → int
The hash code for this object.
no setterinherited
heading → TextStyle
final
ink → Color
final
line → Color
final
micro → TextStyle
final
mono → TextStyle
final
muted → Color
final
raised → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionLabel → TextStyle
final
small → TextStyle
final
surface → Color
final
warn → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

lg → const double
md → const double
radius → const double
radiusSmall → const double
defaultRadii, inlined.
sm → const double
stripHeight → const double
InspectTabStrip.height, inlined — the strip this one stands in for.
xl → const double
xs → const double
xxl → const double
xxs → const double
FwSpacing, inlined.