origin property
Where the app made the event, for an event that said. Never a fact about the difference; a fact about where to go and look.
Implementation
final String? origin;
Where the app made the event, for an event that said. Never a fact about the difference; a fact about where to go and look.
final String? origin;