package property
Which package it came from, worktree-relative, or null on a comparison that recorded none — see ComparedItem.package.
Implementation
final String? package;
Which package it came from, worktree-relative, or null on a comparison that recorded none — see ComparedItem.package.
final String? package;