ComparedHalfKind enum
Which half a row came from.
The halves are named rather than merged because they are compared by different machinery and a row from one is not interchangeable with a row from the other — but the counts merge, because "did this branch break anything" is a question about the branch.
Values
- previews → const ComparedHalfKind
- scenarios → const ComparedHalfKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ComparedHalfKind> - A constant List of the values in this enum, in order of their declaration.