jobs property
How many renders and replays the comparison ran at once — fw compare --jobs. What tells a run that was slow from one that was serial.
Implementation
final int? jobs;
How many renders and replays the comparison ran at once — fw compare --jobs. What tells a run that was slow from one that was serial.
final int? jobs;