exported property
Which of them were written there — see ExportedFrames. Always ExportedFrames.all for a report that was never exported, whose frames are wherever the run left them.
Implementation
final ExportedFrames exported;
Which of them were written there — see ExportedFrames. Always ExportedFrames.all for a report that was never exported, whose frames are wherever the run left them.
final ExportedFrames exported;