host property
Where it ran — see ComparisonHost. Null for a file written before the key existed.
Implementation
final ComparisonHost? host;
Where it ran — see ComparisonHost. Null for a file written before the key existed.
final ComparisonHost? host;