scenariosHalf property
Absent when the project declares no scenarios at all. A half that tried and could not is present, with a ComparedHalf.note.
Implementation
final ComparedHalf? scenariosHalf;
Absent when the project declares no scenarios at all. A half that tried and could not is present, with a ComparedHalf.note.
final ComparedHalf? scenariosHalf;