scenariosNote property
String?
get
scenariosNote
Why the scenario half has nothing to say, when it has nothing to say.
Implementation
String? get scenariosNote => scenariosHalf?.note;
Why the scenario half has nothing to say, when it has nothing to say.
String? get scenariosNote => scenariosHalf?.note;