timings property
Where its time went — see ComparisonTimings. Null for a file written before the key existed.
Implementation
final ComparisonTimings? timings;
Where its time went — see ComparisonTimings. Null for a file written before the key existed.
final ComparisonTimings? timings;