PixelChannel class

Constructors

PixelChannel(PixelDiff diff)
const

Properties

changed → bool
no setter
diff → PixelDiff
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) → PixelChannel
The written form back into a PixelDiff a stage can draw.