TreeDelta class

One thing that is not the same about the two trees.

Constructors

TreeDelta({required TreeDeltaKind kind, required String path, String? property, String? base, String? head})
const
TreeDelta.added(String path, String type)
TreeDelta.removed(String path, String type)

Properties

base → String?
final
hashCode → int
The hash code for this object.
no setterinherited
final
kind → TreeDeltaKind
final
path → String
Where in the tree, as widget names — Column › Card › Padding. Not the node id, which is a child-index path and means nothing to a reader.
final
property → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) → TreeDelta