panelId property

String get panelId

Stable, and unique among the plugins of one devbar. Two devbars mounted at once do not have to coordinate: the bridge disambiguates.

Implementation

String get panelId;