FeatureFlag<T> class

Constructors

FeatureFlag(String name, T defaultValue, {String? description})

Properties

description → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withDefaultValue → FeatureFlagValue<T>
no setter

Methods

dependsOnValue(BuildContext context) → T
findValue(BuildContext context) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
withValue(T newValue) → FeatureFlagValue<T>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

picker<T>(String name, T defaultValue, {String? description, required Map<T, String> options, T? fromJson(Object)?}) → FeatureFlag<T>
slider<T extends num>(String name, T defaultValue, {required T min, required T max, required T step, String? description}) → FeatureFlag<T>