rows property
The row count as the report phrased it (3 rows), or null when the
reporter did not count.
Implementation
final String? rows;
The row count as the report phrased it (3 rows), or null when the
reporter did not count.
final String? rows;