FileVariableStore class

Implemented types

Properties

file → File
final
hashCode → int
The hash code for this object.
no setterinherited
keys → List<String>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ Map<String, Object?>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String key) → Object?
override
operator []=(String key, Object? value) → void
override

Static Methods

load(File dataFile) → Future<FileVariableStore>