landscapeKeypadKeyboard property

double? landscapeKeypadKeyboard
final

The digit pad with the device on its side, and null with the same meaning as keypadKeyboard — no shrink, use the landscape letters height.

Two of the table's phones have this unset because their reading failed its control.

Implementation

final double? landscapeKeypadKeyboard;