linuxLaptop constant

  1. @Deprecated('Renamed: a desktop preview is a window, not a screen. Use ' 'Devices.linuxWindow.')
Device const linuxLaptop

Implementation

@Deprecated(
  'Renamed: a desktop preview is a window, not a screen. Use '
  'Devices.linuxWindow.',
)
static const linuxLaptop = linuxWindow;