wideMonitor constant

  1. @Deprecated('Renamed: a desktop preview is a window, not a screen. Use ' 'Devices.wideWindow.')
Device const wideMonitor

Implementation

@Deprecated(
  'Renamed: a desktop preview is a window, not a screen. Use '
  'Devices.wideWindow.',
)
static const wideMonitor = wideWindow;