windowsLaptop constant

  1. @Deprecated('Renamed: a desktop preview is a window, not a screen. Use ' 'Devices.windowsWindow.')
Device const windowsLaptop

Implementation

@Deprecated(
  'Renamed: a desktop preview is a window, not a screen. Use '
  'Devices.windowsWindow.',
)
static const windowsLaptop = windowsWindow;