width property
Physical pixels — the size of the image that comes out, which is what
the host's CaptureViewport records and what an address names.
Implementation
final double width;
Physical pixels — the size of the image that comes out, which is what
the host's CaptureViewport records and what an address names.
final double width;