orientationById function
The orientation id names, or null for anything unknown.
Implementation
ScreenOrientation? orientationById(String id) =>
ScreenOrientation.values.where((o) => o.name == id).firstOrNull;
The orientation id names, or null for anything unknown.
ScreenOrientation? orientationById(String id) =>
ScreenOrientation.values.where((o) => o.name == id).firstOrNull;