hovering property
String?
get
hovering
What the synthetic mouse is parked over, or null when it is off screen.
Implementation
String? get hovering => _hovering;
What the synthetic mouse is parked over, or null when it is off screen.
String? get hovering => _hovering;