options property
The legal values when kind is ActionParameterKind.choice and the set is small enough to spell out.
Implementation
final List<ActionOption> options;
The legal values when kind is ActionParameterKind.choice and the set is small enough to spell out.
final List<ActionOption> options;