path property
Where it was written, when it was written. Relative to the worktree root so the value survives being read on another machine.
Implementation
final String? path;
Where it was written, when it was written. Relative to the worktree root so the value survives being read on another machine.
final String? path;