workingDirectory property
Where the commands run, relative to the worktree root. The worktree root itself when null.
Implementation
final String? workingDirectory;
Where the commands run, relative to the worktree root. The worktree root itself when null.
final String? workingDirectory;