FuzzyMatch class
A successful match: a score (higher is better) and the character indexes in the target that the query matched, for highlighting.
Constructors
-
FuzzyMatch(int score, List<
int> matched) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited