parameters property

List<ActionParameter> parameters
final

What the action needs to be told, if anything.

An action without parameters is a button. With them it is still one action — a form to the GUI, flags to fw, an argument map to an agent — rather than one action per possible target, which is what encoding the argument into id degenerates into once the targets number in the hundreds.

Implementation

final List<ActionParameter> parameters;