PluginDeclaration class

One declared plugin, as read back by the GUI.

Constructors

PluginDeclaration({required String id, required String label, Map<String, Object?> config = const {}})
const

Properties

config → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) → PluginDeclaration