RendersPackage class

Inheritance

Constructors

RendersPackage(Pkg pkg, {String target = 'lib/renders.dart'})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
no setterinherited
pkg → Pkg
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String
The file declaring the registrar, relative to the package root.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Must include path; the rest is whatever the plugin needs.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited