name property
String
get
name
fake or real — the wire, the flag and the report all say this.
Implementation
String get name => isReal ? 'real' : 'fake';
fake or real — the wire, the flag and the report all say this.
String get name => isReal ? 'real' : 'fake';