TeardownPhase enum

When a teardown step runs relative to the others. Steps run in phase order; the built-in "remove the git worktree" step always runs last.

Inheritance
Available extensions

Values

apps → const TeardownPhase
infra → const TeardownPhase
cleanup → const TeardownPhase

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TeardownPhase>
A constant List of the values in this enum, in order of their declaration.