ViewItem class

One row of a ViewItems list: a name plus optional trailing state.

Constructors

ViewItem(String label, {String? detail, Tone tone = Tone.neutral, Address? address})
const

Properties

address → Address?
Where this row is, when it is a thing rather than a line of output.
final
detail → String?
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tone → Tone
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited