description property
What it sets up, in a sentence or two — who is in it, and what state they start in.
Implementation
final String? description;
What it sets up, in a sentence or two — who is in it, and what state they start in.
final String? description;