describe method
What the shell on screen offers, and what each is currently set to.
Implementation
AxisReport describe() => AxisReport(
entryId: _entryId,
shellId: _shellId,
axes: [..._declared.values],
);
What the shell on screen offers, and what each is currently set to.
AxisReport describe() => AxisReport(
entryId: _entryId,
shellId: _shellId,
axes: [..._declared.values],
);