demoRoot property
Element?
get
demoRoot
The demo's root element, or null before the first build.
Implementation
static Element? get demoRoot => demoKey.currentContext as Element?;
The demo's root element, or null before the first build.
static Element? get demoRoot => demoKey.currentContext as Element?;