asked property
KeyboardVariant?
get
asked
What the app is asking for, or null when it is asking for nothing.
Implementation
KeyboardVariant? get asked => GuestTextInput.instance.asking.value;
What the app is asking for, or null when it is asking for nothing.
KeyboardVariant? get asked => GuestTextInput.instance.asking.value;