revision property
Bumped whenever what is on screen would change, so CatalogKeyboardScope has something to rebuild on.
Implementation
final revision = ValueNotifier<int>(0);
Bumped whenever what is on screen would change, so CatalogKeyboardScope has something to rebuild on.
final revision = ValueNotifier<int>(0);