revision property

ValueNotifier<int> revision
final

Bumped when a value changes, so the widget providing these to the demo has something to rebuild on.

Implementation

final revision = ValueNotifier<int>(0);