platform property
Which keyboard to draw. Null takes the iOS tint, which is also what a device with no platform of its own would be shown on.
Implementation
final DevicePlatform? platform;
Which keyboard to draw. Null takes the iOS tint, which is also what a device with no platform of its own would be shown on.
final DevicePlatform? platform;