hide method
Requests that the text input control is hidden.
This method is called when the input control should hide.
Implementation
@override
void hide() {
_shown = false;
asking.value = null;
}
Requests that the text input control is hidden.
This method is called when the input control should hide.
@override
void hide() {
_shown = false;
asking.value = null;
}