show method
Requests that the text input control is shown.
This method is called when the input control should become visible.
Implementation
@override
void show() {
_shown = true;
asking.value = _asked;
}
Requests that the text input control is shown.
This method is called when the input control should become visible.
@override
void show() {
_shown = true;
asking.value = _asked;
}