InspectErrors class

Everything one entry reported, as of the frames drawn so far.

Constructors

InspectErrors({required String? entryId, required List<InspectError> errors})
const
InspectErrors.fromJson(Map<String, Object?> json)
factory

Properties

entryId → String?
Which entry these are of.
final
errors → List<InspectError>
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const InspectErrors