InspectFlex class
A Row, Column or Flex, as its children experience it.
Constructors
- InspectFlex({required String direction, String? mainAxisAlignment, String? crossAxisAlignment, String? mainAxisSize})
-
const
-
InspectFlex.fromJson(Map<
String, Object?> json) -
factory
Properties
- crossAxisAlignment → String?
-
final
- direction → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAxisAlignment → String?
-
final
- mainAxisSize → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sameAs(
InspectFlex? other) → bool -
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited