WatchBox class

One node's box, in the guest's own coordinates — the space InspectLayout.x reports and a capture is taken in.

Constructors

WatchBox({required String? id, required double x, required double y, required double width, required double height})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final
x → double
final
y → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) → WatchBox