BoundWidgetRender<A> class final

Inheritance

Properties

builder → Widget Function(RenderContext context, A args)
final
hashCode → int
The hash code for this object.
no setterinherited
point → WidgetRender<A>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(RenderContext context, A args) → Widget
buildFromJson(RenderContext context, Map<String, Object?> args) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited