CaptureOptions class
Constructors
- CaptureOptions({TextPolicy text(TextRun run)?, UnsupportedPolicy unsupported = UnsupportedPolicy.rasterize, double rasterScale = 3})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rasterScale → double
-
Pixel ratio for raster patches placed by UnsupportedPolicy.rasterize.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → TextPolicy Function(TextRun run)
-
Called per run, so icons and body text can take different roads.
final
- unsupported → UnsupportedPolicy
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited