text property
Called per run, so icons and body text can take different roads.
Implementation
final TextPolicy Function(TextRun run) text;
Called per run, so icons and body text can take different roads.
final TextPolicy Function(TextRun run) text;