RenderBindings class
The registrar's bindings, collected: what this registry can render.
- Implemented types
Constructors
Properties
-
entries
→ List<
BoundRender> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
document<
A> (DocumentRender< A> point, FutureOr<Document> builder(RenderContext context, A args)) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
widget<
A> (WidgetRender< A> point, Widget builder(RenderContext context, A args)) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String name) → BoundRender?