RenderFont class

A font file the writers may embed or read glyph outlines from, matched to runs by family + bold/italic.

Constructors

RenderFont({required String family, required Uint8List bytes, bool bold = false, bool italic = false})

Properties

bold → bool
final
bytes → Uint8List
final
family → String
final
hashCode → int
The hash code for this object.
no setterinherited
italic → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited