renderProtocolVersion top-level constant
int
const renderProtocolVersion
Bumped when the manifest or the line protocol changes shape.
Implementation
const renderProtocolVersion = 1;
Bumped when the manifest or the line protocol changes shape.
const renderProtocolVersion = 1;