changed property
Steps both runs captured whose records disagree — the pixels, or one of the facets around them. Each says which in ScenarioStepDrift.what.
Implementation
final List<ScenarioStepDrift> changed;
Steps both runs captured whose records disagree — the pixels, or one of the facets around them. Each says which in ScenarioStepDrift.what.
final List<ScenarioStepDrift> changed;