errors property
The failure, when ok is false. The last captured step is the frame just before it.
Implementation
final List<ScenarioRunError> errors;
The failure, when ok is false. The last captured step is the frame just before it.
final List<ScenarioRunError> errors;