animations property
The ticker scale a real run applied — 0.1 by default — or null under
the fake clock, where there is nothing to scale.
Implementation
final double? animations;
The ticker scale a real run applied — 0.1 by default — or null under
the fake clock, where there is nothing to scale.
final double? animations;