carrying method

This package with keep in place of its scenarios, and its counts left as they were — they describe the run, not the copy.

Implementation

ScenarioRunPackage carrying(List<ScenarioRunOutcome> keep) =>
    ScenarioRunPackage(
      path: path,
      output: output,
      axes: axes,
      ms: ms,
      scenarios: keep,
      report: report,
      log: log,
      error: error,
      drift: drift,
      passed: passed,
      failed: failed,
      skipped: skipped,
      unsettledCount: unsettledCount,
      scenariosElided: scenariosElided + scenarios.length - keep.length,
      time: time,
      animations: animations,
    );