error property

String? error
final

Set when the package could not be run at all — the harness did not compile, the tester did not start — in which case scenarios is empty.

Implementation

final String? error;