False when any package failed to run at all, or any scenario it ran came back red — what makes fw run scenarios run exit 1.
fw run scenarios run
@override bool get ok => packages.every( (p) => p.error == null && p.scenarios.every((scenario) => scenario.ok), );