frameIntervalMs property

int? frameIntervalMs
final

Fake milliseconds between two frames — the speed a player runs at to show the animation as the app would have played it.

Implementation

final int? frameIntervalMs;