hasEvents property
bool
get
hasEvents
Whether anything happened on the way to this step.
Implementation
bool get hasEvents => (eventCount ?? 0) > 0;
Whether anything happened on the way to this step.
bool get hasEvents => (eventCount ?? 0) > 0;