repeat method

void repeat({
  1. int? times,
  2. bool yoyo = false,
})

Runs times traversals of the timeline, or forever when null.

yoyo turns around at each end instead of jumping back, so a there- and-back is repeat(times: 2, yoyo: true). A traversal is one crossing of the timeline, which is what makes those two numbers the same number.

Implementation

void repeat({int? times, bool yoyo = false}) =>
    _run(forward: true, times: times, yoyo: yoyo);