ExternalNode.read constructor
ExternalNode.read(
- String entry, {
- String name = '',
- double x = 0,
- double y = 0,
- double? width,
- double? height,
- SceneColor? fill,
- SceneColor? borderColor,
- double borderWidth = 1,
- double corner = 0,
- double? cornerTopLeft,
- double? cornerTopRight,
- double? cornerBottomRight,
- double? cornerBottomLeft,
- double? minWidth,
- double? maxWidth,
- double? minHeight,
- double? maxHeight,
- double opacity = 1,
- bool visible = true,
- Map<
String, Object?> ? args,
A node the tool READ — from a scene file it parsed, or from the wire. It has the label and the values but not the generated class, because the editor does not compile the app.
Implementation
ExternalNode.read(
this.entry, {
super.name,
super.x,
super.y,
super.width,
super.height,
super.fill,
super.borderColor,
super.borderWidth,
super.corner,
super.cornerTopLeft,
super.cornerTopRight,
super.cornerBottomRight,
super.cornerBottomLeft,
super.minWidth,
super.maxWidth,
super.minHeight,
super.maxHeight,
super.opacity,
super.visible,
Map<String, Object?>? args,
}) : declared = null,
args = args ?? {};