RepeatExpr class
- Inheritance
-
- Object
- TimelineExpr
- RepeatExpr
Constructors
- RepeatExpr(int times, TimelineExpr child)
Properties
- child → TimelineExpr
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- times ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited