SceneAlignment class

A point in a box, in the -1..1 space Flutter's Alignment uses — where a gradient starts and ends.

Constructors

SceneAlignment(double x, double y)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toWire() → List<double>

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromWire(Object? raw, SceneAlignment fallback) → SceneAlignment