canPromote property

bool canPromote
final

Whether "make a parameter of this" is possible. A scene parameter has to be able to HOLD the value, and only some types can be one.

Implementation

final bool canPromote;