withStops abstract method
This gradient with other colours at other positions, its shape kept — what every stop edit is.
Implementation
SceneGradient withStops(List<SceneColor> colors, List<double>? stops);
This gradient with other colours at other positions, its shape kept — what every stop edit is.
SceneGradient withStops(List<SceneColor> colors, List<double>? stops);