help property
One line the editor shows under the kind's rows — how the kind is worked on the canvas, when that is not obvious from the rows.
Implementation
final String? help;
One line the editor shows under the kind's rows — how the kind is worked on the canvas, when that is not obvious from the rows.
final String? help;