timeline property
TimelineExpr
get
timeline
What plays. Groups place themselves in it, so nothing is looked up.
Implementation
TimelineExpr get timeline;
What plays. Groups place themselves in it, so nothing is looked up.
TimelineExpr get timeline;