withDefault method

SceneParamDecl withDefault(
  1. Object value
)

The same declaration with a new mockup. A declaration is immutable so that an undo snapshot can hold the list of them as it was; changing a default replaces the entry.

Implementation

SceneParamDecl withDefault(Object value) => SceneParamDecl(name, kind, value);