sides property
For a ScenePropKind.edges: the four file names of the parts, in the
quad's own order — paddingLeft, paddingTop…; cornerTopLeft…
Implementation
final List<String>? sides;
For a ScenePropKind.edges: the four file names of the parts, in the
quad's own order — paddingLeft, paddingTop…; cornerTopLeft…
final List<String>? sides;