ScenePropOwner enum

Which node kinds carry a property.

Inheritance
Available extensions

Values

any → const ScenePropOwner
frame → const ScenePropOwner
text → const ScenePropOwner
shape → const ScenePropOwner
takesArgs → const ScenePropOwner

The two node kinds that stand for something else and pass it arguments.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

has(SceneNode node) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ScenePropOwner>
A constant List of the values in this enum, in order of their declaration.