ScenePropertyKey class

A property, whole: fill, fontSize, style.

Inheritance

Constructors

ScenePropertyKey(SceneProp prop)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
prop → SceneProp
The row this key is about, whole or in part.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited