declared property

SceneRefArgs? declared
getter/setter pair

The typed arguments, when this node was compiled rather than read — const PromoBadgeArgs(label: 'Now open'), whose build is a direct constructor call to the other scene class that the compiler checks.

Implementation

SceneRefArgs? declared;