SceneTextDecorationStyle enum

How that line is drawn; declaration order matches Flutter's, because the bridge indexes it.

Inheritance
Available extensions

Values

solid → const SceneTextDecorationStyle
double → const SceneTextDecorationStyle
dotted → const SceneTextDecorationStyle
dashed → const SceneTextDecorationStyle
wavy → const SceneTextDecorationStyle

Properties

flutter → TextDecorationStyle

Available on SceneTextDecorationStyle, provided by the SceneTextDecorationStyleToFlutter extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SceneTextDecorationStyle>
A constant List of the values in this enum, in order of their declaration.