isOpaque property
bool
get
isOpaque
The app's own object — neither a value the editor renders nor a style.
Implementation
bool get isOpaque => kind == null && !isStyle;
The app's own object — neither a value the editor renders nor a style.
bool get isOpaque => kind == null && !isStyle;