style property
What this run changes about the node's style — null where it changes nothing, which is the ordinary run.
Implementation
final SceneTextStyle? style;
What this run changes about the node's style — null where it changes nothing, which is the ordinary run.
final SceneTextStyle? style;