inheritsFromStyle function

bool inheritsFromStyle(
  1. SceneDocument doc,
  2. SceneNode node,
  3. String prop
)

Whether prop of node is what its style says — set by the style and equal to it. "Equal means inherited": there is no override flag, by decision, so a property overridden back to the style's own value is inherited again and follows the style.

Implementation

bool inheritsFromStyle(SceneDocument doc, SceneNode node, String prop) {
  var style = styleOf(doc, node);
  if (style == null || !style.sets(prop)) return false;
  return sceneValuesEqual(getSceneProperty(node, prop), style.values[prop]);
}