correlationId property
Object?
get
correlationId
The correlation id of the current zone, if an adapter installed one.
Implementation
static Object? get correlationId => Zone.current[requestIdKey];
The correlation id of the current zone, if an adapter installed one.
static Object? get correlationId => Zone.current[requestIdKey];