ServerHello class
What the server answered meta/attach with.
Constructors
Properties
-
channels
→ List<
String> -
final
- eventCount → int
-
How many ring events the replay will deliver.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- pid → int
-
final
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited