baseUrl property
Where the server listens — http://localhost:8080. Load-bearing: it is
what makes the server openable in a browser and what relative
ServerLink.urls resolve against.
Implementation
final String? baseUrl;
Where the server listens — http://localhost:8080. Load-bearing: it is
what makes the server openable in a browser and what relative
ServerLink.urls resolve against.
final String? baseUrl;