ServerLink class

One page worth surfacing, rendered as a clickable link.

Constructors

ServerLink(String label, String url, {String? description})

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
Absolute, or relative to ServerInfo.baseUrl — /health just works.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) → ServerLink?