slug property
The shot's name, slugged — order-placed. An identifier: it is the file
name and the step's address, and it is deliberately not display copy.
Implementation
final String slug;
The shot's name, slugged — order-placed. An identifier: it is the file
name and the step's address, and it is deliberately not display copy.
final String slug;