failed property
Scenarios that failed while producing this set — it is short by whatever they would have captured.
Implementation
final int failed;
Scenarios that failed while producing this set — it is short by whatever they would have captured.
final int failed;