disagrees property
The files and what ran disagree — a stale build, or a value overridden somewhere the files do not know about.
Implementation
final List<ExportedLocaleFinding> disagrees;
The files and what ran disagree — a stale build, or a value overridden somewhere the files do not know about.
final List<ExportedLocaleFinding> disagrees;