id property
String
get
id
catalog/key — what a service knows the string as, and how
TranslationExport.operator [] addresses it.
Implementation
String get id => '$catalog/$key';
catalog/key — what a service knows the string as, and how
TranslationExport.operator [] addresses it.
String get id => '$catalog/$key';