bounded property
bool
get
bounded
Whether this is a real limit rather than an open bound.
Implementation
bool get bounded => clipsChars != null;
Whether this is a real limit rather than an open bound.
bool get bounded => clipsChars != null;