measuredOn property
The device the claim is true for. A max length without its geometry is an opinion.
Implementation
final String? measuredOn;
The device the claim is true for. A max length without its geometry is an opinion.
final String? measuredOn;