charStart property
The span inside its paragraph, so a key sharing a Text with two others
can still be pointed at exactly.
Implementation
final int? charStart;
The span inside its paragraph, so a key sharing a Text with two others
can still be pointed at exactly.
final int? charStart;