cancelled property

bool get cancelled

Whether someone asked the action to stop, or the world is closing. An action that takes time checks it, or awaits whenCancelled.

Implementation

bool get cancelled => _cancelled.isCompleted;