html property
The first text/html part that is not an attachment, decoded, with its
line breaks as \n.
Implementation
final String? html;
The first text/html part that is not an attachment, decoded, with its
line breaks as \n.
final String? html;