text property
The first text/plain part that is not an attachment, decoded, with its
line breaks as \n. A message with no Content-Type is plain text.
Implementation
final String? text;
The first text/plain part that is not an attachment, decoded, with its
line breaks as \n. A message with no Content-Type is plain text.
final String? text;