progress method
A line for whoever is watching the world open: Starting the server.
Implementation
void progress(String message) =>
_send(WorldMessage.progress, {'message': message});
A line for whoever is watching the world open: Starting the server.
void progress(String message) =>
_send(WorldMessage.progress, {'message': message});