items property
How many of the compared things carried it — steps, or entries.
Not the same as count and the more useful of the two in a verdict: four text fields on one screen is one step's problem, and one text field on four screens is the suite's.
Implementation
final int items;