fractionThreshold constant
double
const fractionThreshold
Below this fraction of the frame, the change has to earn its place with a cluster instead.
Implementation
static const fractionThreshold = 0.0005;