DevbarVariable<T> class
Constructors
-
DevbarVariable(VariablesPlugin service, DevbarVariableDefinition<
T> definition, {required FeatureFlagValue<T> ? flagValue})
Properties
- currentValue → T
-
no setter
- defaultValue → T
-
no setter
-
definition
→ DevbarVariableDefinition<
T> -
final
- description → String?
-
no setter
-
flagValue
→ FeatureFlagValue<
T> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
no setter
- overrideValue → T?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → VariablesPlugin
-
final
- storeValue ↔ T?
-
getter/setter pair
-
value
→ Stream<
T> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkbox(
String key, {String? description, bool defaultValue = false}) → DevbarVariableDefinition< bool> -
picker<
T> (String key, {String? description, required T defaultValue, required Map< T, String> options, T? fromJson(Object)?}) → DevbarVariableDefinition<T> -
slider<
T extends num> (String key, {String? description, required T defaultValue, required T min, required T max, required T step}) → DevbarVariableDefinition< T> -
text(
String key, {String? description, String defaultValue = ''}) → DevbarVariableDefinition< String>