linuxLaptop constant
- @Deprecated('Renamed: a desktop preview is a window, not a screen. Use ' 'Devices.linuxWindow.')
Implementation
@Deprecated(
'Renamed: a desktop preview is a window, not a screen. Use '
'Devices.linuxWindow.',
)
static const linuxLaptop = linuxWindow;