wideMonitor constant
- @Deprecated('Renamed: a desktop preview is a window, not a screen. Use ' 'Devices.wideWindow.')
Implementation
@Deprecated(
'Renamed: a desktop preview is a window, not a screen. Use '
'Devices.wideWindow.',
)
static const wideMonitor = wideWindow;