each static method
Every package. Offered because there is nothing to configure per package here — the pubspec is the declaration — so naming them one at a time only creates a chance to forget one.
Implementation
static List<AssetsPackage> each(List<Pkg> packages) => [
for (var pkg in packages) AssetsPackage(pkg),
];