start property
Brings it up. Null for a stack this machine only observes — a shared server, a system postgres — which is a complete declaration and gets a panel with a status and no controls.
Implementation
final StackRun? start;
Brings it up. Null for a stack this machine only observes — a shared server, a system postgres — which is a complete declaration and gets a panel with a status and no controls.
final StackRun? start;