StackCommand class
One more thing a DevStack's CLI can be asked to do.
Constructors
Properties
- argument → String?
-
A free-text argument this command takes —
serviceforrestart,surfaceforopen. Appended tocommand. Null for a command that takes nothing.final - danger → bool
-
Destroys data. Renderers make it distinct and ask first.
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable within the plugin — what
fw run dev_stack <id>names.final - label → String
-
final
- run → StackRun
-
Run as declared, with argument's value appended when one is given.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
How long to wait for this one, overriding DevStack.commandTimeout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, Object?> json) → StackCommand?