InspectErrors class
Everything one entry reported, as of the frames drawn so far.
Constructors
-
InspectErrors({required String? entryId, required List<
InspectError> errors}) -
const
-
InspectErrors.fromJson(Map<
String, Object?> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const InspectErrors