withValue method
The same knob showing value, for a panel that wants to draw the value a
user is choosing before the guest has confirmed it.
Implementation
KnobDescriptor withValue(Object? value) => KnobDescriptor(
name: name,
kind: kind,
value: value,
defaultValue: defaultValue,
min: min,
max: max,
step: step,
description: description,
options: options,
style: style,
);