ripple property
Whether a press sends a ring out. Off for a look that draws its own press feedback, or for a cursor over an app whose own ink ripple is the point.
Implementation
final bool ripple;
Whether a press sends a ring out. Off for a look that draws its own press feedback, or for a cursor over an app whose own ink ripple is the point.
final bool ripple;