ScenarioCueRecord class
A cue that came back from a file rather than from the run that said it.
Constructors
Properties
-
data
→ Map<
String, Object?> -
Its fields, when it implemented ScenarioCueData.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Its
toString.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The name of the class that was emitted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited