holdAfterFirstTap property
How long the app is left running after the first tap — the hold that proves a hold is not a freeze.
Implementation
final Duration holdAfterFirstTap;
How long the app is left running after the first tap — the hold that proves a hold is not a freeze.
final Duration holdAfterFirstTap;