DocumentRender<A> class
final
A render point that composes a whole PDF document itself — multi-page, flowing text, captured widget blocks dropped in as SVG.
- Inheritance
-
- Object
- RenderPoint<
A> - DocumentRender
Constructors
Properties
-
decodeArgs
→ A Function(Map<
String, Object?> json) -
finalinherited
-
encodeArgs
→ Map<
String, Object?> Function(A args) -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited