RenderFont class
A font file the writers may embed or read glyph outlines from, matched to runs by family + bold/italic.
Constructors
- RenderFont({required String family, required Uint8List bytes, bool bold = false, bool italic = false})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited