RenderHost class abstract
What the registrar receives: bind each declared render point to its implementation.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
document<
A> (DocumentRender< A> point, FutureOr<Document> builder(RenderContext context, A args)) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
widget<
A> (WidgetRender< A> point, Widget builder(RenderContext context, A args)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited