RenderPoint<A> class
sealed
A named entry the render guest can produce, with its args type pinned.
Names are slash-pathed (charts/monthly) and unique per registry.
- Implementers
Properties
-
decodeArgs
→ A Function(Map<
String, Object?> json) -
final
-
encodeArgs
→ Map<
String, Object?> Function(A args) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited