TextPolicy enum
What to do with a text run.
Values
- vectorize → const TextPolicy
-
Draw each glyph as a path read from the font file.
- embedFont → const TextPolicy
-
Emit real text and embed the font bytes.
- systemFont → const TextPolicy
-
Emit real text naming the family and let the viewer resolve it.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TextPolicy> - A constant List of the values in this enum, in order of their declaration.