BundleFont class
One font file the guest loads at startup — into the engine for shaping, and as capture bytes for embedding and glyph outlines.
Constructors
- BundleFont({required String family, required String path, bool bold = false, bool italic = false})
-
BundleFont.fromJson(Map<
String, Object?> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited