PagePath class
Properties
- asRelative → PagePath
-
no setter
-
extra
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAbsolute → bool
-
final
-
queryParameters
→ Map<
String, String> -
final
- rootMatch → MatchedPath
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
equalsWithExtra(
PagePath other) → bool -
equalsWithoutExtra(
PagePath other) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subPath(
PagePath subPath, {Map< String, dynamic> ? extra}) → PagePath -
toPath(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override