frameIntervalMs property
Fake milliseconds between two frames — the speed a player runs at to show the animation as the app would have played it.
Implementation
final int? frameIntervalMs;
Fake milliseconds between two frames — the speed a player runs at to show the animation as the app would have played it.
final int? frameIntervalMs;