what property
Which facets of the step differ, from ScenarioDriftFacet — pixels
alone for the everyday case. Empty for a step only one of the runs
captured, which did not differ so much as arrive or leave.
Implementation
final List<String> what;
Which facets of the step differ, from ScenarioDriftFacet — pixels
alone for the everyday case. Empty for a step only one of the runs
captured, which did not differ so much as arrive or leave.
final List<String> what;