SceneKind class
One node kind, as the file, the wire and the editor know it.
Constructors
Properties
- children → bool
-
Whether the file's
children: [...]places nodes under it.final - constructor → String
-
What the file spells — the constructor's name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → String?
-
One line the editor shows under the kind's rows — how the kind is
worked on the canvas, when that is not obvious from the rows.
final
- name → String
-
The wire's and the JSON's
kind, and the node'stypeName.final -
props
→ List<
SceneProp> -
The kind's own rows, after the common ones. Each is a map-backed row
made with SceneProp.value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited