Four numbers that are one when they agree: edges, corners. What the property table needs to spell either as one number or four named parts.
- Implementers
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Object - The one number when they agree, the four otherwise.
-
withSide(
int index, double value) → SceneQuad
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited