ExportedCatalog class
A declared catalog, as the export found it.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keys → int
-
How many keys the files define — the denominator behind
ExportFindings.notReached.
final
-
locales
→ List<
String> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- template → String
-
The locale the source text is written in.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, Object?> json) → ExportedCatalog