TranslationKey class
One catalog read.
Constructors
- TranslationKey(String catalog, String key)
-
const
Properties
- catalog → String
-
Which catalog the key belongs to, as
indexTranslationswas told and astool/flutterware.dartdeclares it.final - hashCode → int
-
The hash code for this object.
no setteroverride
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override