Launch class final
An app to start: one of the entry points the project declares for Run, by
its name, and the knobs its main is called with — by parameter name, as
Run calls it.
Properties
- entrypoint → String
-
A Run entry point's name, as
tool/flutterware.dartdeclares it.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
knobs
→ Map<
String, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited