Person class final
Someone using the system, as World.person declared them.
Constructors
Properties
- app → Launch?
-
What they use; null for a person the script acts for.
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- on → WorldDevice
-
Where app runs.
final
- password → String?
-
final
- phone → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited